package refTests;

import static org.junit.Assert.assertArrayEquals;

import org.junit.Test;

import fr.cnes.celestlab.celestlabx.area.AreaScene;

public class Test01_CLx_stelaArea extends RefTests {

	String[] ids = { "Body", "GS" };
	String[] types = { "Cuboid", "Rectangle" };
    double[][] dims = new double[][] { { 1.0, 1.0, 1.0 }, { 1.0, 1.0, Double.NaN} };

    double[][] z_axis = new double[][] { { 0, 0, 1 }, { 0, 0, 1} };
    double[][] x_axis = new double[][] { { 1, 0, 0}, {1, 0, 0} };
    double[][] orig = new double[][] { { 0, 0, 0}, {0, -1, 0} };

	/**
	 * Equivalent to Scilab test CLx_stela_area.tst - test 1
	 * @throws Exception 
	 */
    @Test
	public void test01() throws Exception {
		initStela();

		AreaScene desc = new AreaScene();
		desc.setShapes(ids, types, dims);
        desc.setShapeFrames(z_axis, x_axis, orig); 
        
		double[] ref = { 1.98 };

		// Test Inputs
		double[][] dirs = new double[][] { { 0, 0, 1 } };

		// Run test
		double[] res = CLx_stela_area(desc, Typ.fix, dirs, 0, null, null, null, null);

		// Compare results
		assertArrayEquals(ref, res, 1E-2);
	}

	/**
	 * Equivalent to Scilab test CLx_stela_area.tst - test 2
	 * @throws Exception 
	 */
    @Test
	public void test02() throws Exception {
		initStela();

		AreaScene desc = new AreaScene();
		desc.setShapes(ids, types, dims);
        desc.setShapeFrames(z_axis, x_axis, orig); 
        
		double[] ref = { 1.84 };

		// Test Inputs
		int nbp = 100;

		// Run test
		double[] res = CLx_stela_area(desc, Typ.tumb, null, nbp, null, null, null, null);

		// Compare results
		assertArrayEquals(ref, res, 1E-2);
	}

    /**
	 * Equivalent to Scilab test CLx_stela_area.tst - test 3
     * @throws Exception 
	 */
    @Test
	public void test03() throws Exception {
		initStela();

		AreaScene desc = new AreaScene();
		desc.setShapes(ids, types, dims);
        desc.setShapeFrames(z_axis, x_axis, orig); 
        
		double[] ref = { 1.26 };

		// Test Inputs
		int nbp = 100;
		double[][] axis = new double[][] { { 0, 0, 1 } };
		double[][] dirs = new double[][] { { 1, 0, 0 } };

		// Run test
		double[] res = CLx_stela_area(desc, Typ.spin, dirs, nbp, null, axis, null, null);

		// Compare results
		assertArrayEquals(ref, res, 1E-2);
	}

    /**
	 * Equivalent to Scilab test CLx_stela_area.tst - test 4
     * @throws Exception 
	 */
    @Test
	public void test04() throws Exception {
		initStela();

		AreaScene desc = new AreaScene();
		desc.setShapes(ids, types, dims);
        desc.setShapeFrames(z_axis, x_axis, orig); 
        
		double[] ref = { 1.98 };

		// Test Inputs
		double[][] dirs = new double[][] { { 1, 0, 0 } };
		String[] ids = new String[] { "GS" };
		double[][] axis = new double[][] { { 0, 1, 0 } };
		double[] angs = new double[] { Math.PI / 2 };
		double[][] cens = new double[][] { { 0, 0, 0 } };

		// Run test
		double[] res = CLx_stela_area(desc, Typ.fixr, dirs, 0, ids, axis, angs, cens);

		// Compare results
		assertArrayEquals(ref, res, 1E-2);
	}

}
